@@ -17,6 +17,16 @@ from ._frozen import FrozenClass
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Slot.Hole.comp_height import comp_height
+except ImportError as error:
+    comp_height = error
+
+try:
+    from ..Methods.Slot.Hole.comp_magnetization_dict import comp_magnetization_dict
+except ImportError as error:
+    comp_magnetization_dict = error
+
 try:
     from ..Methods.Slot.Hole.comp_radius import comp_radius
 except ImportError as error:
@@ -27,11 +37,26 @@ try:
 except ImportError as error:
     comp_surface = error
 
+try:
+    from ..Methods.Slot.Hole.convert_to_UD import convert_to_UD
+except ImportError as error:
+    convert_to_UD = error
+
 try:
     from ..Methods.Slot.Hole.get_is_stator import get_is_stator
 except ImportError as error:
     get_is_stator = error
 
+try:
+    from ..Methods.Slot.Hole.get_magnet_by_id import get_magnet_by_id
+except ImportError as error:
+    get_magnet_by_id = error
+
+try:
+    from ..Methods.Slot.Hole.get_magnet_dict import get_magnet_dict
+except ImportError as error:
+    get_magnet_dict = error
+
 try:
     from ..Methods.Slot.Hole.get_Rbo import get_Rbo
 except ImportError as error:
@@ -52,31 +77,11 @@ try:
 except ImportError as error:
     plot = error
 
-try:
-    from ..Methods.Slot.Hole.comp_height import comp_height
-except ImportError as error:
-    comp_height = error
-
-try:
-    from ..Methods.Slot.Hole.get_magnet_by_id import get_magnet_by_id
-except ImportError as error:
-    get_magnet_by_id = error
-
 try:
     from ..Methods.Slot.Hole.set_magnet_by_id import set_magnet_by_id
 except ImportError as error:
     set_magnet_by_id = error
 
-try:
-    from ..Methods.Slot.Hole.get_magnet_dict import get_magnet_dict
-except ImportError as error:
-    get_magnet_dict = error
-
-try:
-    from ..Methods.Slot.Hole.convert_to_UD import convert_to_UD
-except ImportError as error:
-    convert_to_UD = error
-
 
 from ._check import InitUnKnowClassError
 from .Material import Material
@@ -88,6 +93,27 @@ class Hole(FrozenClass):
     VERSION = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Slot.Hole.comp_height
+    if isinstance(comp_height, ImportError):
+        comp_height = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use Hole method comp_height: " + str(comp_height))
+            )
+        )
+    else:
+        comp_height = comp_height
+    # cf Methods.Slot.Hole.comp_magnetization_dict
+    if isinstance(comp_magnetization_dict, ImportError):
+        comp_magnetization_dict = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Hole method comp_magnetization_dict: "
+                    + str(comp_magnetization_dict)
+                )
+            )
+        )
+    else:
+        comp_magnetization_dict = comp_magnetization_dict
     # cf Methods.Slot.Hole.comp_radius
     if isinstance(comp_radius, ImportError):
         comp_radius = property(
@@ -106,6 +132,17 @@ class Hole(FrozenClass):
         )
     else:
         comp_surface = comp_surface
+    # cf Methods.Slot.Hole.convert_to_UD
+    if isinstance(convert_to_UD, ImportError):
+        convert_to_UD = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Hole method convert_to_UD: " + str(convert_to_UD)
+                )
+            )
+        )
+    else:
+        convert_to_UD = convert_to_UD
     # cf Methods.Slot.Hole.get_is_stator
     if isinstance(get_is_stator, ImportError):
         get_is_stator = property(
@@ -117,6 +154,28 @@ class Hole(FrozenClass):
         )
     else:
         get_is_stator = get_is_stator
+    # cf Methods.Slot.Hole.get_magnet_by_id
+    if isinstance(get_magnet_by_id, ImportError):
+        get_magnet_by_id = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Hole method get_magnet_by_id: " + str(get_magnet_by_id)
+                )
+            )
+        )
+    else:
+        get_magnet_by_id = get_magnet_by_id
+    # cf Methods.Slot.Hole.get_magnet_dict
+    if isinstance(get_magnet_dict, ImportError):
+        get_magnet_dict = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Hole method get_magnet_dict: " + str(get_magnet_dict)
+                )
+            )
+        )
+    else:
+        get_magnet_dict = get_magnet_dict
     # cf Methods.Slot.Hole.get_Rbo
     if isinstance(get_Rbo, ImportError):
         get_Rbo = property(
@@ -153,26 +212,6 @@ class Hole(FrozenClass):
         )
     else:
         plot = plot
-    # cf Methods.Slot.Hole.comp_height
-    if isinstance(comp_height, ImportError):
-        comp_height = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use Hole method comp_height: " + str(comp_height))
-            )
-        )
-    else:
-        comp_height = comp_height
-    # cf Methods.Slot.Hole.get_magnet_by_id
-    if isinstance(get_magnet_by_id, ImportError):
-        get_magnet_by_id = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Hole method get_magnet_by_id: " + str(get_magnet_by_id)
-                )
-            )
-        )
-    else:
-        get_magnet_by_id = get_magnet_by_id
     # cf Methods.Slot.Hole.set_magnet_by_id
     if isinstance(set_magnet_by_id, ImportError):
         set_magnet_by_id = property(
@@ -184,35 +223,20 @@ class Hole(FrozenClass):
         )
     else:
         set_magnet_by_id = set_magnet_by_id
-    # cf Methods.Slot.Hole.get_magnet_dict
-    if isinstance(get_magnet_dict, ImportError):
-        get_magnet_dict = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Hole method get_magnet_dict: " + str(get_magnet_dict)
-                )
-            )
-        )
-    else:
-        get_magnet_dict = get_magnet_dict
-    # cf Methods.Slot.Hole.convert_to_UD
-    if isinstance(convert_to_UD, ImportError):
-        convert_to_UD = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use Hole method convert_to_UD: " + str(convert_to_UD)
-                )
-            )
-        )
-    else:
-        convert_to_UD = convert_to_UD
     # save and copy methods are available in all object
     save = save
     copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
-    def __init__(self, Zh=36, mat_void=-1, init_dict=None, init_str=None):
+    def __init__(
+        self,
+        Zh=36,
+        mat_void=-1,
+        magnetization_dict_offset=None,
+        init_dict=None,
+        init_str=None,
+    ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
@@ -232,10 +256,13 @@ class Hole(FrozenClass):
                 Zh = init_dict["Zh"]
             if "mat_void" in list(init_dict.keys()):
                 mat_void = init_dict["mat_void"]
+            if "magnetization_dict_offset" in list(init_dict.keys()):
+                magnetization_dict_offset = init_dict["magnetization_dict_offset"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.Zh = Zh
         self.mat_void = mat_void
+        self.magnetization_dict_offset = magnetization_dict_offset
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -254,6 +281,11 @@ class Hole(FrozenClass):
             Hole_str += "mat_void = " + tmp
         else:
             Hole_str += "mat_void = None" + linesep + linesep
+        Hole_str += (
+            "magnetization_dict_offset = "
+            + str(self.magnetization_dict_offset)
+            + linesep
+        )
         return Hole_str
 
     def __eq__(self, other):
@@ -265,25 +297,59 @@ class Hole(FrozenClass):
             return False
         if other.mat_void != self.mat_void:
             return False
+        if other.magnetization_dict_offset != self.magnetization_dict_offset:
+            return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+        if other._Zh != self._Zh:
+            diff_list.append(name + ".Zh")
+        if (other.mat_void is None and self.mat_void is not None) or (
+            other.mat_void is not None and self.mat_void is None
+        ):
+            diff_list.append(name + ".mat_void None mismatch")
+        elif self.mat_void is not None:
+            diff_list.extend(
+                self.mat_void.compare(other.mat_void, name=name + ".mat_void")
+            )
+        if other._magnetization_dict_offset != self._magnetization_dict_offset:
+            diff_list.append(name + ".magnetization_dict_offset")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
         S = 0  # Full size of the object
         S += getsizeof(self.Zh)
         S += getsizeof(self.mat_void)
+        if self.magnetization_dict_offset is not None:
+            for key, value in self.magnetization_dict_offset.items():
+                S += getsizeof(value) + getsizeof(key)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         Hole_dict = dict()
         Hole_dict["Zh"] = self.Zh
         if self.mat_void is None:
             Hole_dict["mat_void"] = None
         else:
-            Hole_dict["mat_void"] = self.mat_void.as_dict()
+            Hole_dict["mat_void"] = self.mat_void.as_dict(**kwargs)
+        Hole_dict["magnetization_dict_offset"] = (
+            self.magnetization_dict_offset.copy()
+            if self.magnetization_dict_offset is not None
+            else None
+        )
         # The class name is added to the dict for deserialisation purpose
         Hole_dict["__class__"] = "Hole"
         return Hole_dict
@@ -294,6 +360,7 @@ class Hole(FrozenClass):
         self.Zh = None
         if self.mat_void is not None:
             self.mat_void._set_None()
+        self.magnetization_dict_offset = None
 
     def _get_Zh(self):
         """getter of Zh"""
@@ -344,3 +411,23 @@ class Hole(FrozenClass):
         :Type: Material
         """,
     )
+
+    def _get_magnetization_dict_offset(self):
+        """getter of magnetization_dict_offset"""
+        return self._magnetization_dict_offset
+
+    def _set_magnetization_dict_offset(self, value):
+        """setter of magnetization_dict_offset"""
+        if type(value) is int and value == -1:
+            value = dict()
+        check_var("magnetization_dict_offset", value, "dict")
+        self._magnetization_dict_offset = value
+
+    magnetization_dict_offset = property(
+        fget=_get_magnetization_dict_offset,
+        fset=_set_magnetization_dict_offset,
+        doc=u"""Dictionary add an offset to the magnetization direction of the magnets (key=magnet_X, value=angle[rad])
+
+        :Type: dict
+        """,
+    )
