@@ -95,6 +95,19 @@ class ImportMatrix(Import):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Import
+        diff_list.extend(super(ImportMatrix, self).compare(other, name=name))
+        if other._is_transpose != self._is_transpose:
+            diff_list.append(name + ".is_transpose")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -105,11 +118,15 @@ class ImportMatrix(Import):
         S += getsizeof(self.is_transpose)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Import
-        ImportMatrix_dict = super(ImportMatrix, self).as_dict()
+        ImportMatrix_dict = super(ImportMatrix, self).as_dict(**kwargs)
         ImportMatrix_dict["is_transpose"] = self.is_transpose
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
