@@ -104,6 +104,19 @@ class ImportMatrixVal(ImportMatrix):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from ImportMatrix
+        diff_list.extend(super(ImportMatrixVal, self).compare(other, name=name))
+        if not array_equal(other.value, self.value):
+            diff_list.append(name + ".value")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -114,11 +127,15 @@ class ImportMatrixVal(ImportMatrix):
         S += getsizeof(self.value)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from ImportMatrix
-        ImportMatrixVal_dict = super(ImportMatrixVal, self).as_dict()
+        ImportMatrixVal_dict = super(ImportMatrixVal, self).as_dict(**kwargs)
         if self.value is None:
             ImportMatrixVal_dict["value"] = None
         else:
