@@ -191,6 +191,7 @@ class LamSquirrelCage(LamSlotWind):
         is_stator=True,
         axial_vent=-1,
         notch=-1,
+        yoke_notch=-1,
         init_dict=None,
         init_str=None,
     ):
@@ -243,6 +244,8 @@ class LamSquirrelCage(LamSlotWind):
                 axial_vent = init_dict["axial_vent"]
             if "notch" in list(init_dict.keys()):
                 notch = init_dict["notch"]
+            if "yoke_notch" in list(init_dict.keys()):
+                yoke_notch = init_dict["yoke_notch"]
         # Set the properties (value check and convertion are done in setter)
         self.Hscr = Hscr
         self.Lscr = Lscr
@@ -263,6 +266,7 @@ class LamSquirrelCage(LamSlotWind):
             is_stator=is_stator,
             axial_vent=axial_vent,
             notch=notch,
+            yoke_notch=yoke_notch,
         )
         # The class is frozen (in LamSlotWind init), for now it's impossible to
         # add new properties
