@@ -219,6 +219,21 @@ class SlotCirc(Slot):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Slot
+        diff_list.extend(super(SlotCirc, self).compare(other, name=name))
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -230,11 +245,15 @@ class SlotCirc(Slot):
         S += getsizeof(self.H0)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Slot
-        SlotCirc_dict = super(SlotCirc, self).as_dict()
+        SlotCirc_dict = super(SlotCirc, self).as_dict(**kwargs)
         SlotCirc_dict["W0"] = self.W0
         SlotCirc_dict["H0"] = self.H0
         # The class name is added to the dict for deserialisation purpose
