@@ -277,6 +277,27 @@ class SlotW14(Slot):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Slot
+        diff_list.extend(super(SlotW14, self).compare(other, name=name))
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        if other._H1 != self._H1:
+            diff_list.append(name + ".H1")
+        if other._H3 != self._H3:
+            diff_list.append(name + ".H3")
+        if other._W3 != self._W3:
+            diff_list.append(name + ".W3")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -291,11 +312,15 @@ class SlotW14(Slot):
         S += getsizeof(self.W3)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Slot
-        SlotW14_dict = super(SlotW14, self).as_dict()
+        SlotW14_dict = super(SlotW14, self).as_dict(**kwargs)
         SlotW14_dict["W0"] = self.W0
         SlotW14_dict["H0"] = self.H0
         SlotW14_dict["H1"] = self.H1
