@@ -266,6 +266,21 @@ class SlotW24(Slot):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Slot
+        diff_list.extend(super(SlotW24, self).compare(other, name=name))
+        if other._W3 != self._W3:
+            diff_list.append(name + ".W3")
+        if other._H2 != self._H2:
+            diff_list.append(name + ".H2")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -277,11 +292,15 @@ class SlotW24(Slot):
         S += getsizeof(self.H2)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Slot
-        SlotW24_dict = super(SlotW24, self).as_dict()
+        SlotW24_dict = super(SlotW24, self).as_dict(**kwargs)
         SlotW24_dict["W3"] = self.W3
         SlotW24_dict["H2"] = self.H2
         # The class name is added to the dict for deserialisation purpose
