@@ -145,6 +145,23 @@ class SolutionVector(Solution):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Solution
+        diff_list.extend(super(SolutionVector, self).compare(other, name=name))
+        if (other.field is None and self.field is not None) or (
+            other.field is not None and self.field is None
+        ):
+            diff_list.append(name + ".field None mismatch")
+        elif self.field is not None:
+            diff_list.extend(self.field.compare(other.field, name=name + ".field"))
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -155,11 +172,15 @@ class SolutionVector(Solution):
         S += getsizeof(self.field)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Solution
-        SolutionVector_dict = super(SolutionVector, self).as_dict()
+        SolutionVector_dict = super(SolutionVector, self).as_dict(**kwargs)
         if self.field is None:
             SolutionVector_dict["field"] = None
         else:
