@@ -19,7 +19,7 @@ class Ui_PHoleM57(object):
     def setupUi(self, PHoleM57):
         if not PHoleM57.objectName():
             PHoleM57.setObjectName(u"PHoleM57")
-        PHoleM57.resize(731, 470)
+        PHoleM57.resize(1099, 491)
         PHoleM57.setMinimumSize(QSize(0, 0))
         PHoleM57.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PHoleM57)
@@ -40,146 +40,150 @@ class Ui_PHoleM57(object):
 
         self.horizontalLayout.addWidget(self.img_slot)
 
-        self.widget = QWidget(PHoleM57)
-        self.widget.setObjectName(u"widget")
-        self.widget.setMinimumSize(QSize(250, 0))
-        self.widget.setMaximumSize(QSize(250, 16777215))
-        self.verticalLayout_2 = QVBoxLayout(self.widget)
-        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
+        self.scrollArea = QScrollArea(PHoleM57)
+        self.scrollArea.setObjectName(u"scrollArea")
+        self.scrollArea.setMinimumSize(QSize(270, 0))
+        self.scrollArea.setMaximumSize(QSize(270, 16777215))
+        self.scrollArea.setWidgetResizable(True)
+        self.scrollAreaWidgetContents = QWidget()
+        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 467))
+        self.verticalLayout_3 = QVBoxLayout(self.scrollAreaWidgetContents)
+        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.lf_W3 = FloatEdit(self.widget)
+        self.lf_W3 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_W3.setObjectName(u"lf_W3")
 
         self.gridLayout.addWidget(self.lf_W3, 5, 1, 1, 1)
 
-        self.lf_W0 = FloatEdit(self.widget)
+        self.lf_W0 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_W0.setObjectName(u"lf_W0")
 
         self.gridLayout.addWidget(self.lf_W0, 2, 1, 1, 1)
 
-        self.in_W1 = QLabel(self.widget)
+        self.in_W1 = QLabel(self.scrollAreaWidgetContents)
         self.in_W1.setObjectName(u"in_W1")
 
         self.gridLayout.addWidget(self.in_W1, 3, 0, 1, 1)
 
-        self.lf_H2 = FloatEdit(self.widget)
+        self.lf_H2 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_H2.setObjectName(u"lf_H2")
 
         self.gridLayout.addWidget(self.lf_H2, 1, 1, 1, 1)
 
-        self.unit_W1 = QLabel(self.widget)
+        self.unit_W1 = QLabel(self.scrollAreaWidgetContents)
         self.unit_W1.setObjectName(u"unit_W1")
 
         self.gridLayout.addWidget(self.unit_W1, 3, 2, 1, 1)
 
-        self.lf_H1 = FloatEdit(self.widget)
+        self.lf_H1 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_H1.setObjectName(u"lf_H1")
 
         self.gridLayout.addWidget(self.lf_H1, 0, 1, 1, 1)
 
-        self.unit_W2 = QLabel(self.widget)
+        self.unit_W2 = QLabel(self.scrollAreaWidgetContents)
         self.unit_W2.setObjectName(u"unit_W2")
 
         self.gridLayout.addWidget(self.unit_W2, 4, 2, 1, 1)
 
-        self.in_W3 = QLabel(self.widget)
+        self.in_W3 = QLabel(self.scrollAreaWidgetContents)
         self.in_W3.setObjectName(u"in_W3")
 
         self.gridLayout.addWidget(self.in_W3, 5, 0, 1, 1)
 
-        self.unit_W4 = QLabel(self.widget)
+        self.unit_W4 = QLabel(self.scrollAreaWidgetContents)
         self.unit_W4.setObjectName(u"unit_W4")
 
         self.gridLayout.addWidget(self.unit_W4, 6, 2, 1, 1)
 
-        self.lf_W4 = FloatEdit(self.widget)
+        self.lf_W4 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_W4.setObjectName(u"lf_W4")
 
         self.gridLayout.addWidget(self.lf_W4, 6, 1, 1, 1)
 
-        self.unit_W0 = QLabel(self.widget)
+        self.unit_W0 = QLabel(self.scrollAreaWidgetContents)
         self.unit_W0.setObjectName(u"unit_W0")
 
         self.gridLayout.addWidget(self.unit_W0, 2, 2, 1, 1)
 
-        self.in_W2 = QLabel(self.widget)
+        self.in_W2 = QLabel(self.scrollAreaWidgetContents)
         self.in_W2.setObjectName(u"in_W2")
 
         self.gridLayout.addWidget(self.in_W2, 4, 0, 1, 1)
 
-        self.in_W0 = QLabel(self.widget)
+        self.in_W0 = QLabel(self.scrollAreaWidgetContents)
         self.in_W0.setObjectName(u"in_W0")
 
         self.gridLayout.addWidget(self.in_W0, 2, 0, 1, 1)
 
-        self.in_W4 = QLabel(self.widget)
+        self.in_W4 = QLabel(self.scrollAreaWidgetContents)
         self.in_W4.setObjectName(u"in_W4")
 
         self.gridLayout.addWidget(self.in_W4, 6, 0, 1, 1)
 
-        self.unit_H1 = QLabel(self.widget)
+        self.unit_H1 = QLabel(self.scrollAreaWidgetContents)
         self.unit_H1.setObjectName(u"unit_H1")
 
         self.gridLayout.addWidget(self.unit_H1, 0, 2, 1, 1)
 
-        self.in_H2 = QLabel(self.widget)
+        self.in_H2 = QLabel(self.scrollAreaWidgetContents)
         self.in_H2.setObjectName(u"in_H2")
 
         self.gridLayout.addWidget(self.in_H2, 1, 0, 1, 1)
 
-        self.lf_W2 = FloatEdit(self.widget)
+        self.lf_W2 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_W2.setObjectName(u"lf_W2")
 
         self.gridLayout.addWidget(self.lf_W2, 4, 1, 1, 1)
 
-        self.in_H1 = QLabel(self.widget)
+        self.in_H1 = QLabel(self.scrollAreaWidgetContents)
         self.in_H1.setObjectName(u"in_H1")
 
         self.gridLayout.addWidget(self.in_H1, 0, 0, 1, 1)
 
-        self.unit_W3 = QLabel(self.widget)
+        self.unit_W3 = QLabel(self.scrollAreaWidgetContents)
         self.unit_W3.setObjectName(u"unit_W3")
 
         self.gridLayout.addWidget(self.unit_W3, 5, 2, 1, 1)
 
-        self.lf_W1 = FloatEdit(self.widget)
+        self.lf_W1 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_W1.setObjectName(u"lf_W1")
 
         self.gridLayout.addWidget(self.lf_W1, 3, 1, 1, 1)
 
-        self.unit_H2 = QLabel(self.widget)
+        self.unit_H2 = QLabel(self.scrollAreaWidgetContents)
         self.unit_H2.setObjectName(u"unit_H2")
 
         self.gridLayout.addWidget(self.unit_H2, 1, 2, 1, 1)
 
-        self.verticalLayout_2.addLayout(self.gridLayout)
+        self.verticalLayout_3.addLayout(self.gridLayout)
 
-        self.w_mat_0 = WMatSelect(self.widget)
+        self.w_mat_0 = WMatSelect(self.scrollAreaWidgetContents)
         self.w_mat_0.setObjectName(u"w_mat_0")
         self.w_mat_0.setMinimumSize(QSize(100, 0))
 
-        self.verticalLayout_2.addWidget(self.w_mat_0)
+        self.verticalLayout_3.addWidget(self.w_mat_0)
 
-        self.w_mat_1 = WMatSelect(self.widget)
+        self.w_mat_1 = WMatSelect(self.scrollAreaWidgetContents)
         self.w_mat_1.setObjectName(u"w_mat_1")
         self.w_mat_1.setMinimumSize(QSize(100, 0))
 
-        self.verticalLayout_2.addWidget(self.w_mat_1)
+        self.verticalLayout_3.addWidget(self.w_mat_1)
 
-        self.w_mat_2 = WMatSelect(self.widget)
+        self.w_mat_2 = WMatSelect(self.scrollAreaWidgetContents)
         self.w_mat_2.setObjectName(u"w_mat_2")
         self.w_mat_2.setMinimumSize(QSize(100, 0))
 
-        self.verticalLayout_2.addWidget(self.w_mat_2)
+        self.verticalLayout_3.addWidget(self.w_mat_2)
 
         self.verticalSpacer_2 = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.verticalLayout_2.addItem(self.verticalSpacer_2)
+        self.verticalLayout_3.addItem(self.verticalSpacer_2)
 
-        self.g_output = QGroupBox(self.widget)
+        self.g_output = QGroupBox(self.scrollAreaWidgetContents)
         self.g_output.setObjectName(u"g_output")
         self.g_output.setMinimumSize(QSize(200, 0))
         self.verticalLayout = QVBoxLayout(self.g_output)
@@ -194,9 +198,11 @@ class Ui_PHoleM57(object):
 
         self.verticalLayout.addWidget(self.out_magnet_surface)
 
-        self.verticalLayout_2.addWidget(self.g_output)
+        self.verticalLayout_3.addWidget(self.g_output)
 
-        self.horizontalLayout.addWidget(self.widget)
+        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+
+        self.horizontalLayout.addWidget(self.scrollArea)
 
         QWidget.setTabOrder(self.lf_H1, self.lf_H2)
         QWidget.setTabOrder(self.lf_H2, self.lf_W0)
