@@ -20,7 +20,7 @@ class Ui_PHoleMUD(object):
     def setupUi(self, PHoleMUD):
         if not PHoleMUD.objectName():
             PHoleMUD.setObjectName(u"PHoleMUD")
-        PHoleMUD.resize(813, 467)
+        PHoleMUD.resize(1103, 588)
         PHoleMUD.setMinimumSize(QSize(740, 440))
         PHoleMUD.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PHoleMUD)
@@ -30,18 +30,22 @@ class Ui_PHoleMUD(object):
 
         self.horizontalLayout.addWidget(self.w_viewer)
 
-        self.widget = QWidget(PHoleMUD)
-        self.widget.setObjectName(u"widget")
-        self.widget.setMinimumSize(QSize(250, 0))
-        self.widget.setMaximumSize(QSize(250, 16777215))
-        self.verticalLayout_2 = QVBoxLayout(self.widget)
+        self.scrollArea = QScrollArea(PHoleMUD)
+        self.scrollArea.setObjectName(u"scrollArea")
+        self.scrollArea.setMinimumSize(QSize(270, 0))
+        self.scrollArea.setMaximumSize(QSize(270, 16777215))
+        self.scrollArea.setWidgetResizable(True)
+        self.scrollAreaWidgetContents = QWidget()
+        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 564))
+        self.verticalLayout_2 = QVBoxLayout(self.scrollAreaWidgetContents)
         self.verticalLayout_2.setObjectName(u"verticalLayout_2")
-        self.b_dxf = QPushButton(self.widget)
+        self.b_dxf = QPushButton(self.scrollAreaWidgetContents)
         self.b_dxf.setObjectName(u"b_dxf")
 
         self.verticalLayout_2.addWidget(self.b_dxf)
 
-        self.w_path_json = WPathSelectorV(self.widget)
+        self.w_path_json = WPathSelectorV(self.scrollAreaWidgetContents)
         self.w_path_json.setObjectName(u"w_path_json")
         sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
         sizePolicy.setHorizontalStretch(0)
@@ -51,7 +55,7 @@ class Ui_PHoleMUD(object):
 
         self.verticalLayout_2.addWidget(self.w_path_json)
 
-        self.g_mat = QGroupBox(self.widget)
+        self.g_mat = QGroupBox(self.scrollAreaWidgetContents)
         self.g_mat.setObjectName(u"g_mat")
         self.g_mat_layout = QVBoxLayout(self.g_mat)
         self.g_mat_layout.setObjectName(u"g_mat_layout")
@@ -69,7 +73,7 @@ class Ui_PHoleMUD(object):
 
         self.verticalLayout_2.addItem(self.verticalSpacer)
 
-        self.g_output = QGroupBox(self.widget)
+        self.g_output = QGroupBox(self.scrollAreaWidgetContents)
         self.g_output.setObjectName(u"g_output")
         self.g_output.setMinimumSize(QSize(200, 0))
         self.verticalLayout = QVBoxLayout(self.g_output)
@@ -96,7 +100,9 @@ class Ui_PHoleMUD(object):
 
         self.verticalLayout_2.addWidget(self.g_output)
 
-        self.horizontalLayout.addWidget(self.widget)
+        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+
+        self.horizontalLayout.addWidget(self.scrollArea)
 
         self.retranslateUi(PHoleMUD)
 
@@ -107,7 +113,7 @@ class Ui_PHoleMUD(object):
     def retranslateUi(self, PHoleMUD):
         PHoleMUD.setWindowTitle(QCoreApplication.translate("PHoleMUD", u"Form", None))
         self.b_dxf.setText(
-            QCoreApplication.translate("PHoleMUD", u"Define Slot from DXF", None)
+            QCoreApplication.translate("PHoleMUD", u"Define Hole from DXF", None)
         )
         self.g_mat.setTitle(QCoreApplication.translate("PHoleMUD", u"Materials", None))
         self.g_output.setTitle(QCoreApplication.translate("PHoleMUD", u"Output", None))
