@@ -1,45 +1,45 @@
 # -*- coding: utf-8 -*-
 
-from ....GUI.Dialog.DMachineSetup.SMachineType.SMachineType import SMachineType
-from ....GUI.Dialog.DMachineSetup.SMachineDimension.SMachineDimension import (
-    SMachineDimension,
-)
-from ....GUI.Dialog.DMachineSetup.SLamParam.SLamParam import SLamParam
-from ....GUI.Dialog.DMachineSetup.SWindPat.SWindPat import SWindPat
-from ....GUI.Dialog.DMachineSetup.SWindParam.SWindParam import SWindParam
-from ....GUI.Dialog.DMachineSetup.SWindCond.SWindCond import SWindCond
-from ....GUI.Dialog.DMachineSetup.SWSlot.SWSlot import SWSlot
-from ....GUI.Dialog.DMachineSetup.SWPole.SWPole import SWPole
-from ....GUI.Dialog.DMachineSetup.SBar.SBar import SBar
-from ....GUI.Dialog.DMachineSetup.SMHoleMag.SMHoleMag import SMHoleMag
-from ....GUI.Dialog.DMachineSetup.SMSlot.SMSlot import SMSlot
-
-from ....Classes.Magnet import Magnet
+from ....Classes.HoleM50 import HoleM50
 from ....Classes.LamHole import LamHole
 from ....Classes.LamSlot import LamSlot
 from ....Classes.LamSlotMag import LamSlotMag
 from ....Classes.LamSlotWind import LamSlotWind
 from ....Classes.LamSquirrelCage import LamSquirrelCage
-from ....Classes.MachineIPMSM import MachineIPMSM
-from ....Classes.MachineSyRM import MachineSyRM
+from ....Classes.LamSquirrelCageMag import LamSquirrelCageMag
 from ....Classes.MachineDFIM import MachineDFIM
+from ....Classes.MachineIPMSM import MachineIPMSM
+from ....Classes.MachineLSPM import MachineLSPM
 from ....Classes.MachineSCIM import MachineSCIM
 from ....Classes.MachineSIPMSM import MachineSIPMSM
-from ....Classes.MachineWRSM import MachineWRSM
 from ....Classes.MachineSRM import MachineSRM
+from ....Classes.MachineSyRM import MachineSyRM
+from ....Classes.MachineWRSM import MachineWRSM
 from ....Classes.SlotM10 import SlotM10
-from ....Classes.HoleM50 import HoleM50
-from ....Classes.WindingDW2L import WindingDW2L
-from ....Classes.WindingCW2LT import WindingCW2LT
+from ....Classes.Winding import Winding
 from ....Classes.WindingSC import WindingSC
+from ....GUI.Dialog.DMachineSetup.SBar.SBar import SBar
+from ....GUI.Dialog.DMachineSetup.SLamParam.SLamParam import SLamParam
+from ....GUI.Dialog.DMachineSetup.SMachineDimension.SMachineDimension import (
+    SMachineDimension,
+)
+from ....GUI.Dialog.DMachineSetup.SMachineType.SMachineType import SMachineType
+from ....GUI.Dialog.DMachineSetup.SMHoleMag.SMHoleMag import SMHoleMag
+from ....GUI.Dialog.DMachineSetup.SMSlot.SMSlot import SMSlot
+from ....GUI.Dialog.DMachineSetup.SWindCond.SWindCond import SWindCond
+from ....GUI.Dialog.DMachineSetup.SWinding.SWinding import SWinding
+from ....GUI.Dialog.DMachineSetup.SWPole.SWPole import SWPole
+from ....GUI.Dialog.DMachineSetup.SWSlot.SWSlot import SWSlot
 from ....GUI.Resources import pixmap_dict
 
 # Steps needed to setup a LamSlotWind
-LSW_step = [SLamParam, SWSlot, SWindPat, SWindParam, SWindCond]
+LSW_step = [SLamParam, SWSlot, SWinding, SWindCond]
 # Steps needed to setup a LamSlotWind for the rotor of a WRSM
-LP_step = [SLamParam, SWPole, SWindPat, SWindParam, SWindCond]
+LP_step = [SLamParam, SWPole, SWinding, SWindCond]
 # Steps needed to setup a LamSquirrelCage
 LSC_step = [SLamParam, SWSlot, SBar]
+# Steps needed to setup a LamSquirrelCageMag
+LSCM_step = [SLamParam, SWSlot, SBar, SMHoleMag]
 # Steps needed to setup a LamHole
 LH_step = [SLamParam, SMHoleMag]
 # Steps needed to setup a LamSlot
@@ -52,7 +52,7 @@ S_step = [SMachineType, SMachineDimension]
 # Defaut machine for initialization
 machine1 = MachineSCIM(frame=None, shaft=None)
 machine1.stator = LamSlotWind()
-machine1.stator.winding = WindingDW2L()
+machine1.stator.winding = Winding()
 machine1.rotor = LamSquirrelCage()
 machine1.rotor.winding = WindingSC()
 machine1._set_None()  # Empty machine
@@ -62,9 +62,9 @@ machine1.rotor.is_stator = False
 
 machine4 = MachineDFIM(frame=None, shaft=None)
 machine4.stator = LamSlotWind()
-machine4.stator.winding = WindingDW2L()
+machine4.stator.winding = Winding()
 machine4.rotor = LamSlotWind()
-machine4.rotor.winding = WindingDW2L()
+machine4.rotor.winding = Winding()
 machine4._set_None()  # Empty machine
 machine4.type_machine = 4
 machine4.stator.is_stator = True
@@ -72,7 +72,7 @@ machine4.rotor.is_stator = False
 
 machine5 = MachineSyRM(frame=None, shaft=None)
 machine5.stator = LamSlotWind()
-machine5.stator.winding = WindingDW2L()
+machine5.stator.winding = Winding()
 machine5.rotor = LamHole()
 machine5.rotor.hole = list()
 machine5.rotor.hole.append(HoleM50())
@@ -84,7 +84,7 @@ machine5.rotor.is_stator = False
 
 machine7 = MachineSIPMSM(frame=None, shaft=None)
 machine7.stator = LamSlotWind()
-machine7.stator.winding = WindingDW2L()
+machine7.stator.winding = Winding()
 machine7.rotor = LamSlotMag()
 machine7.rotor.slot = SlotM10()
 machine7._set_None()  # Empty machine
@@ -94,7 +94,7 @@ machine7.rotor.is_stator = False
 
 machine8 = MachineIPMSM(frame=None, shaft=None)
 machine8.stator = LamSlotWind()
-machine8.stator.winding = WindingDW2L()
+machine8.stator.winding = Winding()
 machine8.rotor = LamHole()
 machine8.rotor.hole = list()
 machine8.rotor.hole.append(HoleM50())
@@ -105,9 +105,9 @@ machine8.rotor.is_stator = False
 
 machine9 = MachineWRSM(frame=None, shaft=None)
 machine9.stator = LamSlotWind()
-machine9.stator.winding = WindingDW2L()
+machine9.stator.winding = Winding()
 machine9.rotor = LamSlotWind()
-machine9.rotor.winding = WindingCW2LT()
+machine9.rotor.winding = Winding()
 machine9._set_None()  # Empty machine
 machine9.type_machine = 9
 machine9.stator.is_stator = True
@@ -115,13 +115,23 @@ machine9.rotor.is_stator = False
 
 machine10 = MachineSRM(frame=None, shaft=None)
 machine10.stator = LamSlotWind()
-machine10.stator.winding = WindingDW2L()
+machine10.stator.winding = Winding()
 machine10.rotor = LamSlot()
 machine10._set_None()  # Empty machine
 machine10.type_machine = 10
 machine10.stator.is_stator = True
 machine10.rotor.is_stator = False
 
+machine11 = MachineLSPM(frame=None, shaft=None)
+machine11.stator = LamSlotWind()
+machine11.stator.winding = Winding()
+machine11.rotor = LamSquirrelCageMag()
+machine11.rotor.winding = WindingSC()
+machine11._set_None()  # Empty machine
+machine11.type_machine = 11
+machine11.stator.is_stator = True
+machine11.rotor.is_stator = False
+
 # Dictionnary with all the information to set a SCIM
 SCIM_dict = {
     "machine_type": MachineSCIM,
@@ -199,6 +209,18 @@ SRM_dict = {
     "img": pixmap_dict["SCIM"],
     "txt": "SRM (Switched Reluctance Machine)",
 }
+# Dictionnary with all the information to set a LSPM
+LSPM_dict = {
+    "machine_type": MachineLSPM,
+    "init_machine": machine11,
+    "start_step": S_step,
+    "stator_step": LSW_step,
+    "rotor_step": LSCM_step,
+    "name": "LSPM",
+    "img": pixmap_dict["LSPM"],
+    "txt": "LSPM (Line Start Permanent Magnet)",
+}
+
 # List of machine types available in the GUI
 mach_list = [
     SCIM_dict,
@@ -208,6 +230,7 @@ mach_list = [
     IPMSM_dict,
     WRSM_dict,
     SRM_dict,
+    LSPM_dict,
 ]
 # To find the correct index according to the machine
 mach_index = [mach_dict["machine_type"] for mach_dict in mach_list]
