@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
 from matplotlib.lines import Line2D
+import matplotlib.pyplot as plt
 from matplotlib.pyplot import axis, legend, plot, subplots, title
 from numpy import array, linspace, meshgrid
 
-from ....Functions.Winding.comp_wind_periodicity import comp_wind_periodicity
 from ....Functions.Winding.gen_phase_list import gen_color, gen_name
 
 
-def plot_winding(self, wind_mat=None, all_slot=False, is_show_fig=True):
+def plot_winding(self, wind_mat=None, all_slot=False, is_show_fig=True, save_path=None):
     """Plot the Winding in a matplotlib fig
 
     Parameters
@@ -16,11 +16,13 @@ def plot_winding(self, wind_mat=None, all_slot=False, is_show_fig=True):
     self : LamSlotWind
         A: LamSlotWind object
     wind_mat : numpy.ndarray
-        Winding Matrix, if None will call comp_connection_mat (Default value = None)
+        Winding Matrix, if None will call get_connection_mat (Default value = None)
     all_slot : bool
         True if we plot all slot and false when plotting only needed one(sym)
     is_show_fig : bool
         To call show at the end of the method
+    save_path : str
+        full path including folder, name and extension of the file to save if save_path is not None
     Returns
     -------
     None
@@ -28,7 +30,7 @@ def plot_winding(self, wind_mat=None, all_slot=False, is_show_fig=True):
 
     # We compute the wind_mat only if needed
     if wind_mat is None:
-        wind_mat = self.winding.comp_connection_mat(self.slot.Zs)
+        wind_mat = self.winding.get_connection_mat(self.slot.Zs)
 
     # Number of point on rad and tan direction
     Nrad, Ntan = self.winding.get_dim_wind()
@@ -38,7 +40,7 @@ def plot_winding(self, wind_mat=None, all_slot=False, is_show_fig=True):
     if all_slot:  # Every Slot
         Nplot = Zs
     else:  # Only the needed one (sym)
-        Nperw = comp_wind_periodicity(wind_mat)[0]  # Symmetry of the winding
+        Nperw, _ = self.winding.get_periodicity()  # Symmetry of the winding
         Nplot = Zs // Nperw
 
     qs = wind_mat.shape[3]  # Number of phase
@@ -148,3 +150,7 @@ def plot_winding(self, wind_mat=None, all_slot=False, is_show_fig=True):
 
     if is_show_fig:
         fig.show()
+
+    if save_path is not None:
+        fig.savefig(save_path)
+        plt.close()
