@@ -28,10 +28,22 @@ def comp_surfaces(self):
     # Surface of the ventilation ducts on the yoke
     Svent = self.comp_surface_axial_vent()
 
+    # Compute notches surfaces
+    Snotch = 0
+    if self.notch is not None and len(self.notch) > 0:
+        for notch in self.notch:
+            Snotch += notch.comp_surface()
+    if self.yoke_notch is not None and len(self.yoke_notch) > 0:
+        self.is_internal = not self.is_internal  # To use Ryoke instead of Rbo
+        for yoke_notch in self.yoke_notch:
+            Snotch += yoke_notch.comp_surface()
+        self.is_internal = not self.is_internal  # Revert
+
     return {
-        "Slam": Slam - Svent,
+        "Slam": Slam - Svent - Snotch,
         "Svent": Svent,
         "Syoke": Slam,
         "Steeth": 0,
         "Sslot": 0,
+        "Snotch": Snotch,
     }
